<?php
/*******************************************************************************
License:
	Copyright 2005 Ryan Morehart
	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at
	
	http://www.apache.org/licenses/LICENSE-2.0
	
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
	
Filename: /admin/external_files/delete.php

Purpose: Prompts on deletion of external files.

Processed parameters: (TYPE - NAME - DESCRIPTION - DEFAULT)
	GET - name - Comma separated list of external file's names which are going to
		be deleted.
*******************************************************************************/

require_once '../includes/admin_standard.php';

// Ensure name(s) for file(s) were supplied
if(!isset($_GET['name']) && !isset($_SESSION['saved']['name']))
{
	returnToCaller('No file was specified.');
}

// Store the template name(s)
if(isset($_GET['name']))
{
	$_SESSION['saved']['name'] = $_GET['name'];
}

// Check if user has confirmed delete
if(isset($_POST['deleteconfirm']))
{
	// Go through each file and remove from database
	// Save failed deletions here:
	$failed = array();
	$files = explode(',', $_SESSION['saved']['name']);
	foreach($files as $name)
	{
		if(deleteFile($connection, $name) !== true)
		{
			$failed[] = $name;
		}
	}
	
	// Check if anything failed. Create error message if they did
	if(empty($failed))
	{
		$message = 'The file(s) were successfully deleted.';
	}
	else
	{
		$message = 'The following files were <strong>not</strong> successfully removed: ';
		$message .= implode(', ', $failed);
	}
	
	returnToCaller($message);
}

include '../includes/header.php';
?>
<h1>Removing file(s)</h1>
<p><strong>Warning!</strong> You are about to permanently remove files from this site. Make
sure that you know what you are doing before clicking the Delete button below.</p>

<p>You are about to remove the following files:</p>
<table class='itemlist'>
<tr class='head'>
	<td>Name</td>
	<td>Description</td>
</tr>
<?php
// Generate list from input parameters
$files = explode(',', $_SESSION['saved']['name']);
natcasesort($files);

// Ensure validity of each. Display each valid one
foreach($files as $name)
{
	$current = getFile($connection, $name);
	echo "\n<tr>";
	if($current !== false)
	{
		?>
		<td><?php echo $current['file_name']; ?></td>
		<td><?php echo $current['description']; ?></td>
		<?php
	}
	else
	{
		?>
		<td style='color: #FF0000;'>{$name}</td>";
		<td style='color: #FF0000;'>This file does not exist (This will not affect delete)</td>
		<?php
	}
	echo "\n</tr>";
}
?>
</table>
<input type="submit" value="Delete" name="deleteconfirm" /> <input type="reset" value="Back" onClick="javascript:history.go(-1);" />
<?php
include '../includes/footer.php';
?>