<?php
/*******************************************************************************
License:
	Copyright 2005 Ryan Morehart
	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at
	
	http://www.apache.org/licenses/LICENSE-2.0
	
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
	
Filename: /admin/external_files/edit.php

Purpose: Presents form with the external file's current data and allows it to be changed and updated
	in the database.

Processed parameters: (TYPE - NAME - DESCRIPTION - DEFAULT)
	GET - name - Name of image to be edited.
*******************************************************************************/

require_once '../includes/admin_standard.php';

// Ensure an existent file was supplied
if((!isset($_GET['name']) || !isValidFileName($connection, $_GET['name'], true))
	&& !isset($_SESSION['saved']['name']))
{
	returnToCaller('Non-existent file specified');
}

// Store the file name
if(isset($_GET['name']))
{
	$_SESSION['saved']['name'] = $_GET['name'];
}

//////////////
// Update information of file
if(isset($_POST['infosubmit']))
{
	if(setFileInfo($connection, $_SESSION['saved']['name'], $_POST['name'], $_POST['description']))
	{
		$message = 'The file information was successfully updated.';
		$_SESSION['saved']['name'] = $_POST['name'];
	}
	else
	{
		$message = 'File information update failed.';
	}
}
////////////
// Update file contents
elseif(isset($_POST['filesubmit']))
{
	if(setFileContents($connection, $_SESSION['saved']['name'], $_POST['data']))
	{
		$message = 'The file data was successfully updated.';
	}
	else
	{
		$message = 'File data update failed.';
	}
}

// Get image data
$file = getFile($connection, $_SESSION['saved']['name']);

include '../includes/header.php';
?>
<h1>Editing file <?php echo $_SESSION['saved']['name']; ?></h1>
<p>You are currently editing one of the files in this site.</p>

<h2>File info</h2>
<table>
	<tr>
		<td>Name:</td>
		<td><input type="text" maxlength="255" name="name" value="<?php echo $file['file_name']; ?>" /></td>
	</tr>
	<tr>
		<td>Description:</td>
		<td><input type="text" maxlength="255" name="description" value="<?php echo $file['description']; ?>" /></td>
	</tr>
</table>
<input type="submit" name="infosubmit" value="Update info" />

<h2>File contents</h2>
<p>Below are the contents of this file. You are free to edit it, but be aware that if this file isn't a text
file, you may screw it up.</p>

<textarea cols="<?php echo $admin_large_text_box_width; ?>"
	rows="<?php echo $admin_large_text_box_height; ?>" name="data">
<?php echo str_replace(' ', '&nbsp;', htmlspecialchars($file['data'])); ?>
</textarea><br />
<input type="submit" name="filesubmit" value="Update File" />
<input type="reset" value="Reset" />
<?php
include '../includes/footer.php';
?>