<?php
/*******************************************************************************
License:
	Copyright 2005 Ryan Morehart
	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at
	
	http://www.apache.org/licenses/LICENSE-2.0
	
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
	
Filename: /admin/external_files/list.php

Purpose: Lists the current external files in the database and allows them to be edited, deleted,
	and new ones to be created.
	
Processed parameters: (TYPE - NAME - DESCRIPTION - DEFAULT)
	NONE
*******************************************************************************/

require_once '../includes/admin_standard.php';

// Check for a requested action
///////////
// Delete file(s)
if(isset($_POST['delete']))
{
	// Ensure at least one image is selected
	if(isset($_POST['file']) && count($_POST['file']) >= 1)
	{
		// Create the string of images to be deleted
		$filesToBeDeleted = implode(',', $_POST['file']);
		
		header("Location: delete.php?name=" . urlencode($filesToBeDeleted));
		die();
	}
	else
	{
		$message = 'You must select the file(s) you would like to delete.';
	}
}
///////////
// Edit an file
elseif(isset($_POST['edit']))
{
	// Ensure only one image is selected
	if(isset($_POST['file']) && count($_POST['file']) == 1)
	{
		header("Location: edit.php?name=" . urlencode($_POST['file'][0]));
		die();
	}
	else
	{
		$message = 'You must select the file (only one at a time) you would like to rename.';
	}
}
///////////
// Upload a new image
elseif(isset($_POST['upload']))
{
	if(is_uploaded_file($_FILES['upload_file']['tmp_name']))
	{
		// Create the name for the file
		$name = $_FILES['upload_file']['name'];
		$name = substr($name, 0, strpos($name, '.'));
		$name = ereg_replace('([^a-zA-Z0-9_])', '', $name);
		
		if(addFileToDatabase($connection, $name, $_FILES['upload_file']['type'],
			$_POST['description'], $_FILES['upload_file']['tmp_name']) !== false)
		{
			$message = "The file was successfully uploaded. (It is named '$name')";
		}
		else
		{
			$message = 'The file was not successfully entered into database.';
		}
	}
	else
	{
		$message = 'The file did not successfully upload.';
	}
}
///////////
// Mass file upload
elseif(isset($_POST['mass_upload']))
{
	header('Location: mass_upload.php');
	die();
}

include '../includes/header.php';
?>
<h1>Current External Files</h1>
<p>Below are all the external files currently in the site.</p>
<table class="itemlist">
<tr class="head">
	<td></td>
	<td>Name</td>
	<td>Type</td>
	<td>Description</td>
</tr>
<?php
// Get file list
$files = getFileList($connection);

// Display
if(!empty($files))
{
	foreach($files as $file)
	{
		?>
		<tr>
			<td><input type="checkbox" name="file[]" value="<?php echo $file['file_name']; ?>" /></td>
			<td>
				<a href="../../showfile.php?name=<?php echo $file['file_name']; ?>"
				target="_blank"><?php echo $file['file_name']; ?></a>
			</td>
			<td><?php echo $file['file_type']; ?></td>
			<td><?php echo htmlentities($file['description']); ?></td>
		</tr>
		<?php
	}
}
else
{
	?>
	<tr>
		<td colspan='4'><strong>No files were available.</strong></td>
	</tr>
	<?php
}
?>
<tr>
	<td></td>
	<td><input type="file" name="upload_file" /></td>
	<td></td>
	<td><input type="text" name="description" maxlength="255" /></td>
	<td><input type="submit" name="upload" value="Upload" /></td>
</tr>
</table>
<input type="submit" name="delete" value="Delete" />
<input type="submit" name="edit" value="Edit" />

<h2>Mass upload</h2>
<p>There are two ways to get files onto the site. You can either use the the file selection box and the
corresponding Upload button next to it (above), or you can use an FTP client to move the new files to
<?php echo $external_files_directory; ?>.</p>

<?php
if(function_exists('mime_content_type'))
{
	echo '<input type="submit" name="mass_upload" value="Mass upload" />';
}
else
{
	?>
	<p>We're sorry, but automatic determination of file types isn't possible. Please install or enable
	the	php_mime_magic extension to use the mass upload feature.</p>
	<?php
}
include '../includes/footer.php';
?>