<?php
/*******************************************************************************
License:
	Copyright 2005 Ryan Morehart
	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at
	
	http://www.apache.org/licenses/LICENSE-2.0
	
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
	
Filename: /admin/external_files/mass_upload.php

Purpose: Displays any files other than images currently in the directory specified by
	$external_files_directory and allows their information to be set and automatically added
	to database.

Processed parameters: (TYPE - NAME - DESCRIPTION - DEFAULT)
	NONE
*******************************************************************************/

require_once '../includes/admin_standard.php';

// Check for a requested action
///////////
// Edit an file
if(isset($_POST['upload']))
{
	// Make sure there are actually files that we are adding
	if(!empty($_POST['name']))
	{
		// Go through each file and add to database
		$files = array_keys($_POST['name']);
		$failedDatabaseAdds = array();
		foreach($files as $name)
		{
			$name = rawurldecode($name);
			
			// Figure out this file's extension
			$originalFileName = $_POST['filename'][$name];
			$fileExtension = substr($originalFileName, strrpos($originalFileName, '.') + 1);
			
			// Add to database
			$fileName = "../../$external_files_directory/$originalFileName";
			if(addFileToDatabase($connection, $_POST['name'][$name], mime_content_type($fileName),
				$_POST['description'][$name], $fileName) !== false)
			{
				$failedDatabaseAdds[] = $_POST['name'][$name];
	
				// Database add failed, so don't try to delete the file
				continue;
			}
			
			// Delete old file. If it fails, then... oh well. :)
			@unlink("../../$external_files_directory/$originalFileName");
		}
		
		// Check for failed database adds
		if(empty($failedDatabaseAdds))
		{
			returnToCaller('File upload succeeded.');
		}
		else
		{
			$message = 'The following files were not added successfully: ' . implode(', ', $failedDatabaseAdds);
		}
	}
	else
	{
		$message = 'There are no new files to upload.';
	}
}

include '../includes/header.php';
?>
<h1>Mass File Upload</h1>
<p>Below is a list of the files you are about to put onto the site. Please add the descriptions and change
the names of any files you would like and hit the "Finish upload" button at the bottom of the page to put
them onto the site. Click on (view) next to a file's name to attempt to see it's contents. (Opens a new window)</p>

<table class="itemlist">
<tr class="head">
	<td>Name</td>
	<td>Description</td>
</tr>
<?php
// Get list of files which aren't images in the external files/file/new directory
// Do some preprocessing on names
$newFileDir = opendir("../../$external_files_directory");
$files = array();
while (false !== ($filename = readdir($newFileDir))) {
	if($filename != '.' && $filename != '..'
		&& !strstr(mime_content_type("../../$external_files_directory/$filename"), 'image'))
	{
		$files[] = strtolower($filename);
	}
}
natcasesort($files);

// Display
if(!empty($files))
{
	foreach($files as $file)
	{
		// Get rid of extension
		$fileNameEndPos = strpos($file, '.');
		$fileName = substr($file, 0, $fileNameEndPos);
		
		// Get rid of all invalid chars
		$fileName = rawurlencode(ereg_replace('([^a-zA-Z0-9_])', '', $fileName));
		?>
		
		<tr>
			<td>
				<input type="text" name="name[<?php echo $fileName; ?>]"
					value="<?php echo $fileName; ?>" maxlength="255" />
				
				<a href="../../<?php echo $external_files_directory; ?>/<?php echo rawurlencode($file); ?>"
					target="_blank">(view)</a>
					
				<input type="hidden" name="filename[<?php echo $fileName; ?>]"
					value="<?php echo $file; ?>" />
			</td>
			<td><input type="text" name="description[<?php echo $fileName; ?>]" maxlength="255" /></td>
		</tr>
		<?php
	}
}
else
{
	?>
	<tr>
		<td colspan="2"><strong>There are no new files.</strong></td>
	</tr>
	<?php
}
?>
</table>
<input type="submit" name="upload" value="Complete upload" />
<?php
include '../includes/footer.php';
?>