<?php
/*******************************************************************************
License:
	Copyright 2005 Ryan Morehart
	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at
	
	http://www.apache.org/licenses/LICENSE-2.0
	
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
	
Filename: /admin/images/delete.php

Purpose: Prompts on deletion of images.

Processed parameters: (TYPE - NAME - DESCRIPTION - DEFAULT)
	GET - name - Comma separated list of image names which are going to
		be deleted.
*******************************************************************************/

require_once '../includes/admin_standard.php';

// Ensure name(s) for image(s) were supplied
if(!isset($_GET['name']) && !isset($_SESSION['saved']['name']))
{
	returnToCaller('No image was specified.');
}

// Store the template name(s)
if(isset($_GET['name']))
{
	$_SESSION['saved']['name'] = $_GET['name'];
}

// Check if user has confirmed delete
if(isset($_POST['deleteconfirm']))
{
	// Go through each image and remove from database
	// Save failed deletions here:
	$failed = array();
	$images = explode(',', $_SESSION['saved']['name']);
	foreach($images as $name)
	{
		if(deleteImage($connection, $name) !== true)
		{
			$failed[] = $name;
		}
	}
	
	// Check if anything failed. Create error message if they did
	if(empty($failed))
	{
		$message = 'The images(s) were successfully deleted.';
	}
	else
	{
		$message = 'The following images were <strong>not</strong> successfully removed: ';
		$message .= implode(', ', $failed);
	}
	
	returnToCaller($message);
}

include '../includes/header.php';
?>
<h1>Removing image(s)</h1>
<p><strong>Warning!</strong> You are about to permanently remove images from this site. Make
sure that you know what you are doing before clicking the Delete button below.</p>

<p>You are about to remove the following images:</p>
<table class='itemlist'>
<tr class='head'>
	<td>Image</td>
	<td>Name</td>
	<td>Description</td>
</tr>
<?php
// Generate list from input parameters
$images = explode(',', $_SESSION['saved']['name']);
natcasesort($images);

// Ensure validity of each. Display each valid one
foreach($images as $name)
{
	$current = getImage($connection, $name);
	echo "\n<tr>";
	if($current !== false)
	{
		echo "\n\t<td>" . getImageTag($connection, $name, 100, 100) . "</td>";
		echo "\n\t<td><a href='../../showimage.php?name=" . $current['image_name'] . "'"
				. "target='_blank'>" . $current['image_name'] . "</a></td>";
		echo "\n\t<td>{$current['description']}</td>";
	}
	else
	{
		echo "\n\t<td></td>";
		echo "\n\t<td style='color: #FF0000;'>{$name}</td>";
		echo "\n\t<td style='color: #FF0000;'>This image does not exist (This will not affect delete)</td>";
	}
	echo "\n</tr>";
}
?>
</table>
<input type="submit" value="Delete" name="deleteconfirm" /> <input type="reset" value="Back" onClick="javascript:history.go(-1);" />
<?php
include '../includes/footer.php';
?>