<?php
/*******************************************************************************
License:
	Copyright 2005 Ryan Morehart
	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at
	
	http://www.apache.org/licenses/LICENSE-2.0
	
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
	
Filename: /admin/images/list.php

Purpose: Lists the current images in the database and allows them to be edited, deleted,
	and new ones to be created.
	
Processed parameters: (TYPE - NAME - DESCRIPTION - DEFAULT)
	NONE
*******************************************************************************/

require_once '../includes/admin_standard.php';

// Check for a requested action
///////////
// Delete image(s)
if(isset($_POST['delete']))
{
	// Ensure at least one image is selected
	if(isset($_POST['image']) && count($_POST['image']) >= 1)
	{
		// Create the string of images to be deleted
		$imagesToBeDeleted = implode(',', $_POST['image']);
		
		header("Location: delete.php?name=" . urlencode($imagesToBeDeleted));
		die();
	}
	else
	{
		$message = 'You must select the image(s) you would like to delete.';
	}
}
///////////
// Edit an image
elseif(isset($_POST['edit']))
{
	// Ensure only one image is selected
	if(isset($_POST['image']) && count($_POST['image']) == 1)
	{
		header("Location: edit.php?name=" . urlencode($_POST['image'][0]));
		die();
	}
	else
	{
		$message = 'You must select the image (only one at a time) you would like to rename.';
	}
}
///////////
// Upload a new image
elseif(isset($_POST['upload']))
{
	// Ensure a picture name was entered
	if(!empty($_POST['name']) && isValidImageName($connection, $_POST['name']))
	{
		if(is_uploaded_file($_FILES['upload_image']['tmp_name']))
		{
			if(addImageToDatabase($connection, $_POST['name'], $_FILES['upload_image']['type'],
				$_POST['description'], $_FILES['upload_image']['tmp_name']) !== false)
			{
				$message = 'The image was successfully uploaded.';
				header('Location: edit.php?name=' . $_POST['name']);
				die();
			}
			else
			{
				$message = 'The image was not successfully entered into database.';
			}
		}
		else
		{
			$message = 'The file did not successfully upload.';
		}
	}
	else
	{
		$message = 'You must enter a valid name for the image.';
	}
}
///////////
// Mass image upload
elseif(isset($_POST['mass_upload']))
{
	header('Location: mass_upload.php');
	die();
}

include '../includes/header.php';
?>
<h1>Current Images</h1>
<p>Below are all the images currently in the site. You can use the various buttons to upload new
ones and delete and rename current ones. Click on the image's name to see the full size image
in a new window.</p>
<table class="itemlist">
<tr class="head">
	<td></td>
	<td>Image</td>
	<td>Name</td>
	<td>Description</td>
</tr>
<?php
// Get image list
$images = getImageList($connection);

// Display
if(!empty($images))
{
	foreach($images as $image)
	{
		?>
		<tr>
			<td><input type="checkbox" name="image[]" value="<?php echo $image['image_name']; ?>" /></td>
			<td><?php echo getImageTag($connection, $image['image_name'], 100, 100,
				true); ?></td>
			<td><a href="../../showimage.php?name=<?php echo urlencode($image['image_name']); ?>"
				target="_blank"><?php echo $image['image_name']; ?></a></td>
			<td><?php echo htmlentities($image['description']); ?></td>
		</tr>
		<?php
	}
}
else
{
	?>
	<tr>
		<td colspan='4'><strong>No images were available.</strong></td>
	</tr>
	<?php
}
?>
<tr>
	<td></td>
	<td><input type="file" name="upload_image" /></td>
	<td><input type="text" name="name" maxlength="255" /></td>	
	<td><input type="text" name="description" maxlength="255" /></td>
	<td><input type="submit" name="upload" value="Upload" /></td>
</tr>
</table>
<input type="submit" name="delete" value="Delete" />
<input type="submit" name="edit" value="Edit Information" />

<h2>Mass upload</h2>
<p>There are two ways to get images onto the site. You can either use the the file selection box and the
corresponding Upload button next to it (above), or you can use an FTP client to move the new images to
<?php echo $external_files_directory; ?>.</p>

<?php
if(function_exists('mime_content_type'))
{
	echo '<input type="submit" name="mass_upload" value="Mass upload" />';
}
else
{
	?>
	<p>We're sorry, but automatic determination of file types isn't possible. Please install or enable
	the	php_mime_magic extension to use the mass upload feature.</p>
	<?php
}
include '../includes/footer.php';
?>