<?php
/*******************************************************************************
License:
	Copyright 2005 Ryan Morehart
	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at
	
	http://www.apache.org/licenses/LICENSE-2.0
	
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
	
Filename: /admin/images/mass_upload.php

Purpose: Displays any images currently in the directory specified by $external_files_directory
	and allows their information to be set and automatically added to database.

Processed parameters: (TYPE - NAME - DESCRIPTION - DEFAULT)
	NONE
*******************************************************************************/

require_once '../includes/admin_standard.php';

// Check for a requested action
///////////
// Edit an image
if(isset($_POST['upload']))
{
	// Make sure there are actually images that we are adding
	if(!empty($_POST['name']))
	{
		// Go through each image and add to database
		$images = array_keys($_POST['name']);
		$failedDatabaseAdds = array();
		foreach($images as $name)
		{
			$name = rawurldecode($name);
			
			// Figure out this file's extension
			$originalFileName = $_POST['filename'][$name];
			$fileExtension = substr($originalFileName, strrpos($originalFileName, '.') + 1);
			
			// Add to database
			if(addImageToDatabase($connection, $_POST['name'][$name], $fileExtension,
				$_POST['description'][$name], "../../$external_files_directory/$originalFileName") !== false)
			{
				$failedDatabaseAdds[] = $_POST['name'][$name];
	
				// Database add failed, so don't try to delete the file
				continue;
			}
			
			// Delete old file. If it fails, then... oh well. :)
			@unlink("../../$external_files_directory/$originalFileName");
		}
		
		// Check for failed database adds
		if(empty($failedDatabaseAdds))
		{
			returnToCaller('File upload succeeded.');
		}
		else
		{
			$message = 'The following files were not added successfully: ' . implode(', ', $failedDatabaseAdds);
		}
	}
	else
	{
		$message = 'There are no new images to upload.';
	}
}

include '../includes/header.php';
?>
<h1>Mass Image Upload</h1>
<p>Below is a list of the images you are about to put onto the site. Please add the descriptions and change
the names of any images you would like and hit the "Finish upload" button at the bottom of the page to put
them onto the site. To see an image full screen, click on the image. (Opens in a new window)</p>

<p>The images on this page may take a very long time to display, depending on your connection. This is because
you are downloading the entire image and your browser is resizing it. When it is actually on the website, the
image will be physically resized to fit the area designated for it <em>before</em> it is sent to the user.
This will make it download much quicker.</p>

<table class="itemlist">
<tr class="head">
	<td>Image</td>
	<td>Name</td>
	<td>Description</td>
</tr>
<?php
// Get list of images which are in the external files/image/new directory
// Do some preprocessing on names
$newImageDir = opendir("../../$external_files_directory");
$images = array();
while (false !== ($filename = readdir($newImageDir))) {
	if($filename != '.' && $filename != '..'	
		&& strstr(mime_content_type("../../$external_files_directory/$filename"), 'image'))
	{
		$images[] = strtolower($filename);
	}
}
natcasesort($images);

// Display
if(!empty($images))
{
	foreach($images as $image)
	{
		// Get rid of extension
		$imageNameEndPos = strpos($image, '.');
		$imageName = substr($image, 0, $imageNameEndPos);
		
		// Get rid of all invalid chars
		$imageName = rawurlencode(ereg_replace('([^a-zA-Z0-9_])', '', $imageName));
		?>
		
		<tr>
			<td><a href="../../<?php echo $external_files_directory; ?>/<?php echo rawurlencode($image); ?>"
				target="_blank"><img
				src="../../<?php echo $external_files_directory; ?>/<?php echo rawurlencode($image); ?>" style="height: 100px; width: 100px;" /></a>
			</td>
			<td>
				<input type="text" name="name[<?php echo $imageName; ?>]"
					value="<?php echo $imageName; ?>" maxlength="255" />
				
				<input type="hidden" name="filename[<?php echo $imageName; ?>]"
					value="<?php echo $image; ?>" />
			</td>
			<td><input type="text" name="description[<?php echo $imageName; ?>]" maxlength="255" /></td>
		</tr>
		<?php
	}
}
else
{
	?>
	<tr>
		<td colspan="3"><strong>There are no new images.</strong></td>
	</tr>
	<?php
}
?>
</table>
<input type="submit" name="upload" value="Complete upload" />
<?php
include '../includes/footer.php';
?>