<?php
/*******************************************************************************
License:
	Copyright 2005 Ryan Morehart
	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at
	
	http://www.apache.org/licenses/LICENSE-2.0
	
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
	
Filename: /admin/includes/admin_standard.php

Purpose: Includes standard things (through /includes/user_standard.php), as well as many
	things specific to the administrative end. Performs checks to make sure the user is logged
	in and has permission to perform the action they request.

Processed parameters: (TYPE - NAME - DESCRIPTION - DEFAULT)
	GET/POST - style - toggles additional style sheets
	GET/POST - referer - adds the specified page to the referer list, which is used when
		a page wishes to return to the one which called it
*******************************************************************************/

// Standard includes
require_once "../../includes/user_standard.php";
require_once "../includes/loggedin.php";
require_once "../includes/common.php";
require_once "../includes/users.php";
require_once "../includes/log.php";
require_once "../includes/actionlist.php";

// Check if site is locked
if($lock_administrative_site)
{
	?>
	<html>
	<head>
		<title>Site locked</title>
	</head>
	<body>
		<h1>Site locked</h1>
		<p>The administrative section of this site has been locked by an administrator. Please try again
		later or contact the administrator at
		<a href="mailto:<?php echo $administrator_email; ?>"><?php echo $administrator_email; ?></a>.</p>
	</body>
	</html>
	<?php
	die();
}

require_once "../includes/checkpermissions.php";

if($write_to_log)
{
	require_once "../includes/writetolog.php";
}

// Check if we have returned to a 'list' action type
// Clear saved data if it has
if($actionType == 'list')
{
	if(isset($_SESSION['saved']))
	{
		unset($_SESSION['saved']);
	}
}

// Save the referer get variable (if any)
if(isset($_REQUEST['referer']))
{
	// Make sure the last referer isn't the same as this one (probably a refresh,
	// so we don't want to add that...)
	if(!isset($_SESSION['referer']) || count($_SESSION['referer']) < 1
		|| $_SESSION['referer'][count($_SESSION['referer']) - 1]
		!= $_REQUEST['referer'])
	{
		$_SESSION['referer'][] = $_REQUEST['referer'];
	}
}

// Save the style request (if any)
if(isset($_REQUEST['style']))
{
	// Add to list if it isn't already there. Take it off it is
	if(isset($_SESSION['style']))
	{
		$place = array_search($_REQUEST['style'], $_SESSION['style']);
	}
	else
	{
		$place = false;
	}
	
	if($place === false)
	{
		$_SESSION['style'][] = $_REQUEST['style'];
	}
	else
	{
		unset($_SESSION['style'][$place]);
	}
	
	// Redirect back to same page to get rid of request data
	header('Location: ' . $_SERVER['PHP_SELF']);
	die();
}
	
// Prevent caching of all admin pages
session_cache_limiter('nocache');
?>