<?php
/*******************************************************************************
License:
	Copyright 2005 Ryan Morehart
	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at
	
	http://www.apache.org/licenses/LICENSE-2.0
	
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
	
Filename: /admin/loops/delete.php

Purpose: Prompts on deletion of page loops.

Processed parameters: (TYPE - NAME - DESCRIPTION - DEFAULT)
	GET - name - Comma separated list of loop display numbers which are going to
		be deleted.
*******************************************************************************/

require_once '../includes/admin_standard.php';

// Ensure name(s) for loop(s) were supplied
if(!isset($_GET['name']) && !isset($_SESSION['saved']['name']))
{
	returnToCaller('No loops were specified.');
}

// Store the loop name(s)
if(isset($_GET['name']))
{
	$_SESSION['saved']['name'] = $_GET['name'];
}
if(isset($_GET['page']))
{
	$_SESSION['saved']['page'] = $_GET['page'];
}

// Extract the actual loops which are to be deleted from string
$loops = explode(';', $_SESSION['saved']['name']);
$loops = array_map(create_function('$a', 'return explode(\'.\', $a);'), $loops);

// Check if user has confirmed delete
if(isset($_POST['deleteconfirm']))
{
	// Go through each loop and remove from database
	// Save failed deletions here:
	$failed = array();
	foreach($loops as $loopIDInfo)
	{
		foreach($loops as $currLoop)
		{
			$loopName = $currLoop[0];
			unset($currLoop[0]);
			foreach($currLoop as $loopDisp)
			{
				if(deleteLoopInstance($connection, $_SESSION['saved']['page'], $loopName, $loopDisp) !== true)
				{
					$failed[] = $name;
				}
			}
		}
	}
	
	// Clean loop list
	cleanLoopList($connection, true);
	
	// Check if anything failed. Create error message if they did
	if(empty($failed))
	{
		$message = 'The loop(s) were successfully deleted.';
	}
	else
	{
		$message = 'The following loops were <strong>not</strong> successfully removed: ';
		$message .= implode(', ', $failed);
	}
	
	returnToCaller($message);
}

include '../includes/header.php';
?>
<h1>Removing loop(s)</h1>
<p><strong>Warning!</strong> You are about to permanently remove data which is
contained in loops from this site. Make sure that you know what you are doing
before clicking the Delete button below.</p>

<p>Are you sure you sure you want to delete the loops listed below?
<?php
foreach($loops as $currLoop)
{
	echo "<h2>$currLoop[0]</h2>\n";
	unset($currLoop[0]);
	?>
	<table class="itemlist">
		<tr class="head"><td>Display order number</td></tr>
		<?php
		foreach($currLoop as $loopDisp)
		{
			echo "\n\t\t<tr><td>$loopDisp</td></tr>";
		}
		?>
	</table>
	<?php
}
?>
<input type="submit" value="Delete" name="deleteconfirm" />
<input type="reset" value="Back" onClick="javascript:history.go(-1);" />
</p>
<?php
include '../includes/footer.php';
?>