<?php
/*******************************************************************************
License:
	Copyright 2005 Ryan Morehart
	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at
	
	http://www.apache.org/licenses/LICENSE-2.0
	
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
	
Filename: /admin/loop/edit.php

Purpose: Presents form with current loop data and allows it to be changed and updated
	in the database.

Processed parameters: (TYPE - NAME - DESCRIPTION - DEFAULT)
	GET - name - Name of loop to be edited.
*******************************************************************************/

require_once '../includes/admin_standard.php';

// Store the page and/or loop name
if(isset($_GET['page']))
{
	$_SESSION['saved']['page'] = $_GET['page'];
}
if(isset($_GET['loop']))
{
	$_SESSION['saved']['loop'] = $_GET['loop'];
}

// Ensure an existent page was supplied
if(!isset($_SESSION['saved']['page']))
{
	returnToCaller('Non-existent page specified');
}

// Separate the loop name from the actual loop instance
$temp = explode('.', $_SESSION['saved']['loop']);
$loopName = $temp[0];
$dispNumber = $temp[1];

//////////////
// Loop data update
if(isset($_POST['datasubmit']))
{
	// Create data string
	// Separate out the things which should be saved
	$dataString = '';
	foreach($_POST as $name => $data)
	{
		if(strstr($name, $admin_data_marker))
		{
			// Get rid of marker
			$actualName = substr($name, strlen($admin_data_marker));
			$dataString .= $actualName . $page_name_sep . $data . $page_data_sep;
		}
	}
	// Strip off ending $page_data_sep marker
	$dataString = substr($dataString, 0, strlen($dataString) - strlen($page_data_sep));

	if(setLoopInstanceData($connection, $_SESSION['saved']['page'], $loopName, $dispNumber, $dataString))
	{
		returnToCaller('The loop data was successfully updated.');
	}
	else
	{
		$message = 'Saving of the loop data failed.';
	}
}

// Get page data
$page = getPage($connection, $_SESSION['saved']['page']);

// Get the template this page uses. We'll use this to request the correct stuff
$template = getTemplate($connection, $page['template_name'], false);
$templateNeeds = parseTemplate($connection, $template, false);

// Check if the loop requested is valid
if(!isset($templateNeeds[$loopName]) || !is_array($templateNeeds[$loopName]))
{
	returnToCaller('The loop you requested doesn\'t exist.');
}

include '../includes/header.php';
?>
<h1>Editing loop <?php echo $loopName; ?> on page <?php echo $_SESSION['saved']['page']; ?></h1>
<p>You are currently editing an instance of a loop. If you would like to view the page this loop is on,
it is available <a href='/showpage.php?page=<?php echo $_SESSION['saved']['page']; ?>' target='_blank'>here</a>.
(Link opens in a new window)</p>

<h2>Loop data</h2>
<table class='itemlist'>
	<tr class='head'>
		<td>Name</td>
		<td>Data</td>
	</tr>
	<?php
	// Get image list. We do this here to avoid the potentially multiptle times it would be called
	// if done in the loop
	$images = getImageList($connection);
	
	$loopNeeds = $templateNeeds[$loopName];
	foreach($loopNeeds as $name => $type)
	{
		echo "\n\t<tr>\n\t\t<td valign='top'>$name</td>\n\t\t<td>";
		
		// Choose what sort of box to output depending on type
		switch(strtolower($type))
		{			
		// Picture/image
		case 'p':
			echo "<select name='{$admin_data_marker}{$name}'>";
			echo "\n\t<option value=''>None</option>";
			
			// Loop through the images
			foreach($images as $image)
			{
				echo "\n\t<option value='" . $image['image_name'] . "'";
				
				if($image['image_name'] == @$page['content'][$loopName][$dispNumber][$name])
				{
					echo " selected='true'";
				}
				
				echo ">" . $image['image_name'] . "</option>";
			}
			
			echo "\n</select>";
			break;
		
		// File
		case 'f':
			echo "<select name='{$admin_data_marker}{$name}'>";
			echo "\n\t<option value=''>None</option>";
			
			// Loop through the files
			foreach($files as $file)
			{
				echo "\n\t<option value='" . $file['file_name'] . "'";
				
				if($file['file_name'] == @$page['content'][$loopName][$dispNumber][$name])
				{
					echo " selected='true'";
				}
				
				echo ">" . $file['file_name'] . "</option>";
			}
			
			echo "\n</select>";
			break;
		
		// Substitution (default)
		case 's':
		default:
			echo "<textarea cols='{$admin_text_box_width}'
				rows='{$admin_text_box_height}' name='{$admin_data_marker}{$name}'>";
			echo (isset($page['content'][$loopName][$dispNumber][$name])
				? htmlspecialchars($page['content'][$loopName][$dispNumber][$name]) : '');
			echo "</textarea>";
		}
		
		echo "</td>\n\t</tr>";
	}
	?>
</table>
<input type="submit" name="datasubmit" value="Update loop data" />
<?php
include '../includes/footer.php';
?>