<?php
/*******************************************************************************
License:
	Copyright 2005 Ryan Morehart
	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at
	
	http://www.apache.org/licenses/LICENSE-2.0
	
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
	
Filename: /admin/misc/install.php

Purpose: Installs CMSmelborp

Processed parameters: (TYPE - NAME - DESCRIPTION - DEFAULT)
	None
*******************************************************************************/

require_once "../../includes/settings.php";

session_start();

$seed = explode(' ', microtime());
srand($seed[0] * 10000);

$adminPassword = '';
for($i = 0; $i < 8; $i++)
{
	$adminPassword .= chr(rand(40, 90));
}
// Remove 0s and O and convert both to o, because they're hard to tell apart
$adminPassword = str_replace(array('0', 'O'), array('o', 'o'), $adminPassword);
$adminPasswordHashed = md5($adminPassword);

$adminUsername = '';
for($i = 0; $i < 8; $i++)
{
	$adminUsername .= chr(rand(97, 122));
}

$schema = <<<END_SCHEMA
DROP TABLE IF EXISTS external_files;
CREATE TABLE external_files (
  file_name varchar(255) NOT NULL default '',
  file_type varchar(255) default NULL,
  description varchar(255) default NULL,
  data blob NOT NULL,
  PRIMARY KEY  (file_name),
  UNIQUE KEY file_name (file_name)
);

DROP TABLE IF EXISTS images;
CREATE TABLE images (
  image_name varchar(255) NOT NULL default '',
  image_type varchar(5) default NULL,
  description varchar(255) default NULL,
  image_data blob NOT NULL,
  PRIMARY KEY  (image_name),
  UNIQUE KEY image_name (image_name)
);

DROP TABLE IF EXISTS log;
CREATE TABLE log (
  entry_id smallint(5) unsigned NOT NULL auto_increment,
  entry_date int(11) NOT NULL default '0',
  entry_category varchar(255) default NULL,
  entry_type varchar(255) default NULL,
  user_name varchar(255) default NULL,
  extra_information varchar(255) default NULL,
  PRIMARY KEY  (entry_id),
  KEY user_name_2 (user_name)
);

DROP TABLE IF EXISTS page_loop_data;
CREATE TABLE page_loop_data (
  page_name varchar(255) NOT NULL default '',
  loop_name varchar(255) NOT NULL default '',
  display_order smallint(5) unsigned NOT NULL default '0',
  data text,
  KEY page_name (page_name),
  KEY loop_name (loop_name)
);

DROP TABLE IF EXISTS page_main_data;
CREATE TABLE page_main_data (
  page_name varchar(255) NOT NULL default '',
  data text,
  PRIMARY KEY  (page_name),
  UNIQUE KEY page_name (page_name)
);

DROP TABLE IF EXISTS pages;
CREATE TABLE pages (
  page_name varchar(255) NOT NULL default '',
  template_name varchar(255) NOT NULL default '',
  linked_data_page tinyint(1) default NULL,
  description varchar(255) default NULL,
  PRIMARY KEY  (page_name),
  UNIQUE KEY page_name (page_name)
);

DROP TABLE IF EXISTS templates;
CREATE TABLE templates (
  template_name varchar(25) NOT NULL default '',
  description varchar(255) default NULL,
  html text,
  inclusion tinyint(1) NOT NULL default '0',
  linked_data_page tinyint(1) default NULL,
  PRIMARY KEY  (template_name),
  UNIQUE KEY template_name (template_name)
);

DROP TABLE IF EXISTS users;
CREATE TABLE users (
  user_name varchar(255) NOT NULL default '',
  password varchar(32) default NULL,
  permissions varchar(255) default NULL,
  PRIMARY KEY  (user_name),
  UNIQUE KEY user_name (user_name)
);

LOCK TABLES users WRITE;
INSERT INTO users VALUES ('$adminUsername','$adminPasswordHashed','+all');
UNLOCK TABLES;
END_SCHEMA;

if(isset($_SESSION['step']) && $_SESSION['step'] > 0)
{
	switch($_SESSION['step'])
	{
	case 1:
		// Start install
		// Connect to database
		$connection = @mysql_connect($db_host, $db_user, $db_pass);
		if($connection === false)
		{
			$text = '<p>The installer could not connect to the database/the username and password supplied
					in settings.php were incorrect. Please check to make sure that the settings are correct
					and that the MySQL server is running. Resolve the problem and click the button below
					to try again.</p>';
			$next = 1;
			break;
		}
		if(mysql_query("USE $db_data;") === false)
		{
			$text = '<p>The database specified in settings.php does not appear to exist or the user that
					you have given doesn\'t have permission to access it. Please check to make sure
					that the settings are correct and that the user specified in settings.php has
					permission to access the database. Resolve the problem and click the button below
					to try again.</p>';
			$next = 1;
			break;
		}
		if(mysql_query("SELECT page_name FROM pages;", $connection) !== false)
		{
			$text = '<p>CMSmelborp appears to be already installed on this server. If you wish to reinstall
					it, please remove all of it\'s tables from the database and click the button below.</p>
					
					<p>If you are a visitor, this website can be viewed
					<a href="../../showpage.php">here</a>. If you are an administrator, you can edit
					the website by going to the	<a href="welcome.php">administrative</a> section.';
			$next = 1;
			break;
		}
		
		// Create tables and populate with data
		$commands = preg_split('/\s*;\s*/', $schema);
		$failed = array();
		foreach($commands as $current)
		{
			if(mysql_query($current . ';', $connection) === false)
			{
				$failed[] = $current;
			}
		}
		
		// Failed count can be one because of the closing ;
		if(count($failed) <= 1)
		{
			$text = "<p>CMSmelborp has been successfully installed. There is one user currently in the 
						database.</p>
						
					<p>The user's current information:</p>
					<table>
						<tr>
							<td>Username:</td>
							<td><span style='background-color: #DDDDDD;'>$adminUsername</span></td>
						</tr>
						<tr>
							<td>Password:</td>
							<td><span style='background-color: #DDDDDD;'>$adminPassword</span></td>
						</tr>
					</table>
						
					<p>Write down their information and click the button below to remove this installer
					to prevent it from being used again. If you do not want to remove this file (there is a
					safety check, so you're probably okay leaving it), just go straight to the
					<a href=\"welcome.php\">administrative</a> section and login.</p>
					
					<p>Note: The username and password are both case sensitive. There may be punctuation
					characters in the password.</p>";
			$next = 2;
			break;
		}
		else
		{
			$text = '<p>CMSmelborp did not install succesfully. Check your settings and database user
					permissions and try again by clicking the button below.</p>';
			$next = 1;
			break;
		}
		break;
	
	case 2:
		// Remove file
		if(@unlink('install.php'))
		{
			@unlink('../../install.php');
			header('Location: admin.php');
		}
		else
		{
			$text = '<p>The installer script was not succesfully removed. Please manually remove install.php
						or click the button below to try again.</p>
					
					<p>Once you do, go to the <a href="welcome.php">administrative</a> section of the site
					to login and create new users.</p>';
			$next = 2;
		}
		break;
		
	default:
		$text = '<p>A non-existent step was specified. Click the button below to begin installation at
				the beginning.</p>';
		$next = 0;
	}
}
else
{
	$text = '<p>This file will install CMSmelborp into the database. Before beginning, please make
			sure you edit includes/settings.php to tell this installer how to access your database.
			(The database must already be created. This installer only creates the tables and fills
			them with sample data.)</p>

			<p>After you\'ve made the necessary changes to settings.php, click the button below to
			begin installation.</p>
			
			<p>If you are a visitor, this website can be viewed
			<a href="../../showpage.php">here</a>.</p>';
	$next = 1;
}

$_SESSION['step'] = $next;

include "../includes/header.php";
?>
<h1>CMSmelborp installer</h1>

<?php echo $text; ?>

<!-- Button to go onto next step -->
<input type="submit" value="Next step" />

<?php
include "../includes/footer.php";
?>