<?php
/*******************************************************************************
License:
	Copyright 2005 Ryan Morehart
	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at
	
	http://www.apache.org/licenses/LICENSE-2.0
	
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
	
Filename: /admin/misc/welcome.php

Purpose: Prompts user to login.

Processed parameters: (TYPE - NAME - DESCRIPTION - DEFAULT)
	NONE
*******************************************************************************/

require_once '../../includes/user_standard.php';
require_once '../includes/users.php';
require_once '../includes/actionlist.php';

// This odd sequence is designed to destroy any current session the user may have,
// then get rid of it (so they aren't logged in), and finally create a new one
session_start();
session_destroy();
session_start();

////////////
// Attempt to login
if(isset($_POST['login']))
{
	$permissions = validateUser($connection, $_POST['user'], $_POST['password']);
	if($permissions !== false)
	{
		// Setup session
		$_SESSION['user'] = $_POST['user'];
		$_SESSION['permissions'] = $permissions;
		
		// Send to welcome page
		$message = 'You successfully logged in.';
		header('Location: welcome.php?message=' . urlencode($message));
		die();
	}
	else
	{
		$message = 'Invalid username/password combination.';
	}
}

include '../includes/header.php';
?>
<h1>Login</h1>
<p>Please login using the form below. CMSmelborp uses cookies to keep track of your session, so you must
have them turned on and allowed from <?php echo $_SERVER['SERVER_NAME']; ?>. (They are only session
cookies and will be removed when you close your browser window. Please see the
<a href="../misc/privacy_policy.php">privacy policy</a>.)</p>

<p>If you have forgotten your password, there is no way to recover it, but it can be reset. Please email
<a href="mailto:<?php echo $administrator_email; ?>"><?php echo $administrator_email; ?></a> with
your request.</p>

<table>
<tr>
	<td>User:</td>
	<td><input type="text" name="user" /></td>
</tr>
<tr>
	<td>Password:</td>
	<td><input type="password" name="password" /></td>
</tr>
</table>
<input type="submit" name="login" value="Login" />
<input type="reset" value="Reset" />

<p>If you are not a site administrator, please return to the <a href='/showpage.php'>main part</a> of
the site or go <a href="javascript:history.go(-1);">back</a> to where you came from.</p>
<?php
include '../includes/footer.php';
?>