<?php
/*******************************************************************************
License:
	Copyright 2005 Ryan Morehart
	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at
	
	http://www.apache.org/licenses/LICENSE-2.0
	
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
	
Filename: /admin/pages/delete.php

Purpose: Prompts on deletion of pages.

Processed parameters: (TYPE - NAME - DESCRIPTION - DEFAULT)
	GET - name - Comma separated list of pages names which are going to
		be deleted.
*******************************************************************************/

require_once '../includes/admin_standard.php';

// Ensure name(s) for template(s) were supplied
if(!isset($_GET['name']) && !isset($_SESSION['saved']['name']))
{
	returnToCaller('No page was specified.');
}

// Store the template name(s)
if(isset($_GET['name']))
{
	$_SESSION['saved']['name'] = $_GET['name'];
}

// Check if user has confirmed delete
if(isset($_POST['deleteconfirm']))
{
	// Go through each template and remove from database
	// Save failed deletions here:
	$failed = array();
	$pages = explode(',', $_SESSION['saved']['name']);
	foreach($pages as $name)
	{
		if(deletePage($connection, $name) !== true)
		{
			$failed[] = $name;
		}
	}
	
	// Check if anything failed. Create error message if they did
	if(empty($failed))
	{
		$message = 'The page(s) were successfully deleted.';
	}
	else
	{
		$message = 'The following pages were <strong>not</strong> successfully removed: ';
		$message .= implode(', ', $failed);
	}
	
	returnToCaller($message);
	die();
}

include '../includes/header.php';
?>
<h1>Removing page(s)</h1>
<p><strong>Warning!</strong> You are about to permanently remove pages from this site. Make
sure that you know what you are doing before clicking the Delete button below.</p>

<p>You are about to remove the following pages:
<table class='itemlist'>
<tr class='head'>
	<td>Name</td>
	<td>Template</td>
	<td>Description</td>
</tr>
<?php
// Generate list from input parameters
$pages = explode(',', $_SESSION['saved']['name']);
natcasesort($pages);

// Ensure validity of each. Display each valid one
foreach($pages as $name)
{
	$current = getPage($connection, $name);
	echo "\n<tr>";
	if($current !== false)
	{
		echo "\n\t<td><a href='../../showpage.php?page=" . $current['page_name'] . "'
			target='_blank'>" . $current['page_name'] . "</a></td>";
		echo "\n\t<td>{$current['template_name']}</td>";
		echo "\n\t<td>{$current['description']}</td>";
	}
	else
	{
		echo "\n\t<td style='color: #FF0000;'>{$name}</td>";
		echo "\n\t<td></td>";
		echo "\n\t<td style='color: #FF0000;'>This page does not exist (This will not affect delete)</td>";
	}
	echo "\n</tr>";
}
?>
</table>
<input type="submit" value="Delete" name="deleteconfirm" /> <input type="reset" value="Back" onClick="javascript:history.go(-1);" />
</p>
<?php
include '../includes/footer.php';
?>