<?php
/*******************************************************************************
License:
	Copyright 2005 Ryan Morehart
	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at
	
	http://www.apache.org/licenses/LICENSE-2.0
	
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
	
Filename: /admin/pages/edit.php

Purpose: Presents form with current page data and allows it to be changed and updated
	in the database.

Processed parameters: (TYPE - NAME - DESCRIPTION - DEFAULT)
	GET - name - Name of page to be edited.
*******************************************************************************/

require_once '../includes/admin_standard.php';

// Ensure an existent page was supplied
if(!isset($_GET['name']) && !isset($_SESSION['saved']['name']))
{
	returnToCaller('No page specified');
}

// Store the page name and linked page setting
if(isset($_GET['name']))
{
	$_SESSION['saved']['name'] = $_GET['name'];
}
if(isset($_GET['linked_page']))
{
	$_SESSION['saved']['linked_page'] = true;
}

//////////////
// Update information of page
if(isset($_POST['infosubmit']))
{
	if(setPageInfo($connection, $_SESSION['saved']['name'], $_POST['name'], $_POST['template_name'], $_POST['description']))
	{
		$message = 'The page information was successfully updated.';
	}
	else
	{
		$message = 'Page information update failed.';
	}
}
//////////////
// Main data update
elseif(isset($_POST['datasubmit']))
{
	// Create data string	
	// Separate out the things which should be saved
	$dataString = '';
	foreach($_POST as $name => $data)
	{
		if(strstr($name, $admin_data_marker))
		{
			// Get rid of marker
			$actualName = substr($name, strlen($admin_data_marker));
			$dataString .= $actualName . $page_name_sep . $data . $page_data_sep;
		}
	}
	// Strip off ending $page_data_sep marker
	$dataString = substr($dataString, 0, strlen($dataString) - strlen($page_data_sep));
	
	if(setPageMainData($connection, $_SESSION['saved']['name'], $dataString))
	{
		$message = 'The main data was successfully updated.';
	}
	else
	{
		$message = 'Saving of the main page data failed.';
	}
}
//////////////
// Delete loop(s)
elseif(isset($_POST['deleteloopinstance']))
{
	// Ensure that at least one loop is selected
	if(isset($_POST['loop']))
	{
		$loopsToBeRemoved = '';
		foreach($_POST['loop'] as $loopName => $loops)
		{
			$loopsToBeRemoved .= $loopName . '.';
			foreach($loops as $loopDisp)
			{
				$loopsToBeRemoved .= $loopDisp . '.';
			}
			$loopsToBeRemoved = substr($loopsToBeRemoved, 0, strlen($loopsToBeRemoved) - 1);
			$loopsToBeRemoved .= ';';
		}
		$loopsToBeRemoved = substr($loopsToBeRemoved, 0, strlen($loopsToBeRemoved) - 1);
		
		header('Location: ../loops/delete.php?name=' . urlencode($loopsToBeRemoved) . '&page=' . urlencode($_SESSION['saved']['name']));
	}
	else
	{
		$message = 'You must select the loops you would like to delete.';
	}
}
//////////////
// Edit loop
elseif(isset($_POST['editloopinstance']))
{
	// Ensure that only one loop is selected
	if(isset($_POST['loop']) && count($_POST['loop']) == 1)
	{
		$loopName = array_keys($_POST['loop']);
		$loopName = $loopName[0];
		$loopDisp = $_POST['loop'][$loopName][0];
		header("Location: ../loops/edit.php?referer=pages/edit&page="
			. $_SESSION['saved']['name'] . "&loop={$loopName}.{$loopDisp}");
		die();
	}
	else
	{
		$message = 'You must select the loop (only one) you would like to edit.';
	}
}
//////////////
// Move loop(s) up or down
elseif(isset($_POST['moveloopinstanceup']) || isset($_POST['moveloopinstancedown']))
{
	// Ensure that at least one loop is selected
	if(isset($_POST['loop']) && count($_POST['loop']) >= 1)
	{
		// Figure out which direction we are supposed to move it
		if(isset($_POST['moveloopinstanceup']))
		{
			$direction = 1;
		}
		else
		{
			$direction = -1;
		}
		
		// Go through each selected loop
		// Save failures here:
		$failed = array();
		foreach($_POST['loop'] as $loopName => $loopDisps)
		{
			foreach($loopDisps as $loopDisp)
			{
				if(moveLoopInstance($connection, $_SESSION['saved']['name'], $loopName, $loopDisp, $direction) === false)
				{
					$failed[] = $loopName . '=>' . $loopDisp;
				}
			}
		}
		
		if(empty($failed))
		{
			$message = 'Loop move succeeded.';
		}
		else
		{
			$message = 'The following loops were not moved successfully: ' . implode(',', $failed);
		}
	}
	else
	{
		$message = 'You must select the loops you would like to move.';
	}
}
//////////////
// _Possibly_ create loop
else
{
	// Make sure this isn't just a display of the editing page without any a request
	if(isset($_POST) && !empty($_POST))
	{
		// Find the which loop creation button was pressed and separate the
		// loop name from createnewloopinstance part
		$createLoop = array_keys($_POST);
		$createLoop = array_filter($createLoop,
			create_function('$a', 'return strstr($a, "createnewloopinstance");'));
		$createLoop = array_pop($createLoop);
		$createLoop = substr($createLoop, strpos($createLoop, '_') + 1);
		
		// Attempt to create loop
		if(createLoopInstance($connection, $_SESSION['saved']['name'], $createLoop))
		{
			$message = 'Loop instance successfully created.';
			header('Location: ../loops/edit.php?referer=pages/edit&page='
				. $_SESSION['saved']['name'] . '&loop=' . $_POST['name'] . '&message=' . urlencode($message));
			die();
		}
		else
		{
			$message = 'Loop instance creation failed.';
		}
	}
}

// Get page data
$page = getPage($connection, $_SESSION['saved']['name']);

// Get the template this page uses. We'll use this to request the correct stuff
if(!isset($_SESSION['saved']['linked_page']))
{
	$template = getTemplate($connection, $page['template_name']);
}
else
{
	$template = getTemplate($connection, $page['template_name'], false);
}
$templateNeeds = parseTemplate($connection, $template, false);

include '../includes/header.php';
?>
<h1>Editing page <?php echo $_SESSION['saved']['name']; ?></h1>
<p>You are currently editing the content of one of the pages in this site. If you would like to view this page,
it is available <a href='/showpage.php?page=<?php echo $_SESSION['saved']['name']; ?>' target='_blank'>here</a>.
(Link opens in a new window)</p>

<?php
// Only allow page info editing if it isn't a linked data page
if(!isset($_SESSION['saved']['linked_page']) || $_SESSION['saved']['linked_page'] != true)
{
	?>
	<h2>Page info</h2>
	<table>
		<tr>
			<td>Name:</td>
			<td><input type="text" maxlength="255" name="name" value="<?php echo $page['page_name']; ?>" /></td>
		</tr>
		<tr>
			<td>Template used:</td>
			<td>
				<select name="template_name">
				<?php
					$templates = getTemplateList($connection);
					$templates = array_filter($templates, create_function('$a', 'return ($a[\'inclusion\'] == true ? false : true);'));
					foreach($templates as $current)
					{
						echo "\n\t\t\t\t<option value='" . $current['template_name'] . "'";
						if($current['template_name'] == $page['template_name'])
						{
							echo ' selected=\'true\'';
						}
						echo '>' . $current['template_name'] . '</option>';
					}
				?>
				</select>
			</td>
		</tr>
		<tr>
			<td>Description:</td>
			<td><input type="text" maxlength="255" name="description" value="<?php echo $page['description']; ?>" /></td>
		</tr>
	</table>
	<input type="submit" name="infosubmit" value="Update info" />
	<?php
}
?>

<h2>Main data</h2>
<?php
// Check if the template could not be found
if($template !== false)
{
	?>
	<p>The fields below allow you to change the main (non-repeating) data on this page.</p>
	<table class='itemlist'>
		<tr class='head'>
			<td>Name</td>
			<td>Data</td>
		</tr>
		<?php
		// Get image and file lists. We do this here to avoid the potentially multiptle times they
		// would be called if done in the loop
		$images = getImageList($connection);
		$files = getFileList($connection);
	
		$mainNeeds = array_filter($templateNeeds, create_function('$a', 'return !is_array($a);'));
		foreach($mainNeeds as $name => $type)
		{
			echo "\n\t<tr>";
			echo "\n\t\t<td valign='top'>$name</td>\n\t\t<td>";
			
			// Choose what sort of box to output depending on type
			switch(strtolower($type))
			{			
			// Picture/image
			case 'p':
				echo "<select name='{$admin_data_marker}{$name}'>";
				echo "\n\t<option value=''>None</option>";
				
				// Loop through the images
				foreach($images as $image)
				{
					echo "\n\t<option value='" . $image['image_name'] . "'";
					
					if($image['image_name'] == @$page['content'][$name])
					{
						echo " selected='true'";
					}
					
					echo ">" . $image['image_name'] . "</option>";
				}
				
				echo "\n</select>";
				break;
			
			// File
			case 'f':
				echo "<select name='{$admin_data_marker}{$name}'>";
				echo "\n\t<option value=''>None</option>";
				
				// Loop through the files
				foreach($files as $file)
				{
					echo "\n\t<option value='" . $file['file_name'] . "'";
					
					if($file['file_name'] == @$page['content'][$name])
					{
						echo " selected='true'";
					}
					
					echo ">" . $file['file_name'] . "</option>";
				}
				
				echo "\n</select>";
				break;
			
			// Substitution (default)
			case 's':
			default:
				echo "<textarea cols='{$admin_text_box_width}'
					rows='{$admin_text_box_height}' name='{$admin_data_marker}{$name}'>";
				echo (isset($page['content'][$name]) ? htmlspecialchars($page['content'][$name]) : '');
				echo "</textarea>";
			}
			
			echo "\n\t\t</td>\n\t</tr>";
		}
		?>
	</table>
	<input type="submit" name="datasubmit" value="Update main data" />
	
	<?php
	$loops = array_filter($templateNeeds, create_function('$a', 'return is_array($a);'));
	if(!empty($loops))
	{
		?>
		<h2>Repeating data</h2>
		<p>Below is a list of the data in the various loops (repeating sections) on this page.
		Use the various options to edit the data. The data which is displayed is the first
		dynamic entry which will be used by the page. It is intended to help you in identifying
		the individual instances of each loop.</p>
		
		<?php
		// Display loops
		foreach($loops as $loopName => $loopNeeds)
		{
			?>
			<h3><?php echo $loopName; ?></h3>
			<table class='itemlist'>
				<tr class='head'>
					<td></td>
					<td>Sample Data (<?php $temp = array_keys($loopNeeds); echo $temp[0]; ?>)</td>
				</tr>
				<?php
				if(isset($page['content'][$loopName]) && is_array($page['content'][$loopName]))
				{
					foreach($page['content'][$loopName] as $number => $data)
					{
						echo "\n\t\t\t<tr>";
						echo "\n\t\t\t\t<td><input type='checkbox' name='loop[$loopName][]' value='$number' /></td>";
						echo "\n\t\t\t\t<td>";
						echo array_shift($data);
						echo "</td>";
						echo "\n\t\t\t</tr>";
					}
				}
				else
				{
					echo "<tr><td colspan='2'><strong>";
					echo "There are no instances of this loop currently on this page!";
					echo "</strong></td></tr>";
				}
				?>
				<tr>
					<td colspan="2"><strong>Press the button to the right to create a new instance of the loop.</strong></td>
					<td><input type="submit" name="createnewloopinstance_<?php echo $loopName; ?>" value="Create new" /></td>
				</tr>
			</table>
			<table>
				<tr>
					<td>
						<input type="submit" name="editloopinstance" value="Edit" />
						<input type="submit" name="deleteloopinstance" value="Delete" />
					</td>
					<td>
						<table class="layout">
							<tr><td><input type="submit" name="moveloopinstanceup" value="Move up" /></td></tr>
							<tr><td><input type="submit" name="moveloopinstancedown" value="Move down" /></td></tr>
						</table>
					</td>
				</tr>
			</table>
			<?php
		}
	}
}
else
{
	// The template was not successfully retrieved
	// Tell user how to fix the problem
	?>
	<p>The template for this page was not retrieved from the database, probably because
	it has been deleted from the site. The data on this page has not been lost. The easiest way
	to repair this problem is to select a template which uses the same data items as
	<?php echo $page['template_name']; ?> did.</p>
	<?php
}

include '../includes/footer.php';
?>