<?php
/*******************************************************************************
License:
	Copyright 2005 Ryan Morehart
	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at
	
	http://www.apache.org/licenses/LICENSE-2.0
	
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
	
Filename: /admin/pages/list.php

Purpose: Lists the current pages in the database and allows them to be edited, deleted,
	and new ones to be created.
	
Processed parameters: (TYPE - NAME - DESCRIPTION - DEFAULT)
	NONE
*******************************************************************************/

require_once '../includes/admin_standard.php';

// Check for any requested actions
// Create new
if(isset($_POST['create']))
{
	// Ensure that a (valid) name was entered
	if(isValidPageName($connection, $_POST['name'], false))
	{
		// Create page
		if(createPage($connection, $_POST['name'], $_POST['template'], $_POST['description']))
		{
			$message = 'The page was successfully created.';
			header('Location: edit.php?name=' . $_POST['name']);
		}
		else
		{
			$message = 'The page was not successfully created.';
		}
	}
	else
	{
		$message = 'You must enter a <em>valid</em> name.';
	}
}
/////////
// Edit
elseif(isset($_POST['edit']))
{
	// Ensure that a page (and only one), was selected
	if(isset($_POST['page']) && count($_POST['page']) == 1)
	{
		header("Location: edit.php?name={$_POST['page'][0]}");	
	}
	else
	{
		$message = "You must select a page (only one at a time) you would like to edit.";
	}
}
/////////
// Delete
elseif(isset($_POST['delete']))
{
	// Ensure that at least one page was selected
	if(isset($_POST['page']) && count($_POST['page']) >= 1)
	{
		// Save the page names so that they can be used in the redirect
		$pagesToBeRemoved = implode(',', $_POST['page']);
		header("Location: delete.php?name={$pagesToBeRemoved}");		
	}
	else
	{
		$message = "You must select the page(s) you would like to remove.";
	}
}

include '../includes/header.php';
?>
<h1>Current Pages</h1>
<p>Below is a list of pages currently in this site. Select pages by clicking on the check box next to the
one you want. Use the buttons below the list to perform actions on the selected pages. Some options are only
available for one item at a time. You can view a page by clicking on it's name. (It will open in a new
window.)</p>
<table class="itemlist">
	<tr class="head">
		<td></td>
		<td>Name</td>
		<td>Template</td>
		<td>Description</td>
	</tr>
	<?php
	// Display list of pages
	$pages = getPageList($connection, false);
	if(is_array($pages) && !empty($pages))
	{
		foreach($pages as $current)
		{
			?>
			<tr>
				<td><input type="checkbox" name="page[]" value="<?php echo $current['page_name']; ?>" /></td>
				<td>
					<a href="../../showpage.php?page=<?php echo $current['page_name']; ?>"
						target="_blank"><?php echo $current['page_name']; ?></a>
				</td>
				<td><?php echo $current['template_name']; ?></td>
				<td><?php echo $current['description']; ?></td>
			</tr>
			<?php
		}
	}
	else
	{
		?>
		<tr>
			<td colspan='4'><strong>No pages were available.</strong></td>
		</tr>
		<?php
	}
	?>
	<tr>
		<td></td>
		<td><input type="text" maxlength="255" name="name" /></td>
		<td>
			<select name="template">
			<?php
				$templates = getTemplateList($connection);
				$templates = array_filter($templates, create_function('$a', 'return ($a[\'inclusion\'] == true ? false : true);'));
				foreach($templates as $current)
				{
					echo "\n\t\t\t\t<option value='" . $current['template_name'] . "'>";
					echo $current['template_name'];
					echo "</option>";
				}
			?>
			</select>
		</td>
		<td><input type="text" maxlength="255" name="description" /></td>
		<td><input type="submit" name="create" value="Create New" /></td>
	</tr>
</table>
<input type="submit" name="edit" value="Edit" />
<input type="submit" name="delete" value="Delete" />
<?php
include '../includes/footer.php';
?>