<?php
/*******************************************************************************
License:
	Copyright 2005 Ryan Morehart
	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at
	
	http://www.apache.org/licenses/LICENSE-2.0
	
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
	
Filename: /admin/template/edit.php

Purpose: Presents form with current template data and allows it to be changed and updated
	in the database.

Processed parameters: (TYPE - NAME - DESCRIPTION - DEFAULT)
	GET - name - Name of template to be edited.
*******************************************************************************/

require_once '../includes/admin_standard.php';

// Ensure an existent template was supplied
if((!isset($_GET['name']) || !isValidTemplateName($connection, $_GET['name'], true))
	&& !isset($_SESSION['name']))
{
	returnToCaller('Non-existent template specified');
}

// Store the template name
if(isset($_GET['name']))
{
	$_SESSION['name'] = $_GET['name'];
}

//////////////
// Update information of template (not html)
if(isset($_POST['infosubmit']))
{
	if(setTemplateInfo($connection, $_SESSION['name'], $_POST['name'], $_POST['description'],
		isset($_POST['inclusion']), isset($_POST['linked_data_page'])))
	{
		$message = 'Template successfully updated.';
		$_SESSION['name'] = $_POST['name'];
	}
	else
	{
		$message = 'Template update failed.';
	}
}
//////////////
// Update html
elseif(isset($_POST['htmlsubmit']))
{
	// Put new html in database
	if(setTemplateHTML($connection, $_SESSION['name'], $_POST['html']))
	{
		$message = 'Template successfully updated.';
	}
	else
	{
		$message = 'Template update failed.';
	}
}

// Get template data
$template = getTemplate($connection, $_SESSION['name'], false);

include '../includes/header.php';
?>
<h1>Editing template <?php echo $template['template_name']; ?></h1>
<p>You are currently editing a template on this site. Be aware that some changes can cause loss of data. Currently,
CMSmelborp doesn't check to see if any of the pages which use this template have potentially valuable information,
so you'll have to be the judge of that yourself. If you aren't sure, check with someone else before doing <em>anything</em>
on this page.</p>
<p>A preview of this template can be seen <a href="../../showtemplate.php?template=<?php echo $template['template_name']; ?>"
target="_blank">here</a>. (Opens in a new window.)</p>


<h2>Template info</h2>
<table>
	<tr>
		<td>Name:</td>
		<td><input type="text" maxlength="255" name="name" value="<?php echo $template['template_name']; ?>" /></td>
	</tr>
	<tr>
		<td>Description:</td>
		<td><input type="text" maxlength="255" name="description" value="<?php echo $template['description']; ?>" /></td>
	</tr>
	<tr>
		<td>Inclusion:</td>
		<td><input type="checkbox" name="inclusion" <?php echo ($template['inclusion'] == true ? 'checked="true"' : ''); ?> /></td>
	</tr>
	<tr>
		<td>Linked data page:</td>
		<td>
			<?php
			// Linked data page? Give a link to edit it if there is one
			if($template['linked_data_page'] == true)
			{
				echo "<input type='checkbox' name='linked_data_page' checked='true' />";
				echo "<a href='../pages/edit.php?name=" . $linked_data_page_name_prefix
					. $template['template_name']	. "&amp;linked_page'>(Edit)</a>";
			}
			else
			{
				echo "<input type='checkbox' name='linked_data_page' />";
			}
			?>
		</td>
	</tr>
</table>
<input type="submit" name="infosubmit" value="Update info" />


<h2>Template HTML</h2>

<p>In the box below you can edit the HTML this template uses. Before doing this, it is highly recommened you learn
about the syntax you should use for marking locations in the code which you would like to be supplied by pages (entered
dynamically). Some <a href="../help/help.php?topic=template_syntax" target="_blank">help</a> can be read
here, but it's highly recomended you read the entire manual.</p>

<p>If you change any of the special marker tags in the HTML, be aware that some pages may lose data. The invalid data will still
be stored in the page until the next time it is updated.</p>

<textarea cols="<?php echo $admin_large_text_box_width; ?>"
	rows="<?php echo $admin_large_text_box_height; ?>" name="html">
<?php echo str_replace(' ', '&nbsp;', htmlspecialchars($template['html'])); ?>
</textarea><br />
<input type="submit" name="htmlsubmit" value="Update HTML" />
<input type="reset" value="Reset" />
<?php
include '../includes/footer.php';
?>