<?php
/*******************************************************************************
License:
	Copyright 2005 Ryan Morehart
	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at
	
	http://www.apache.org/licenses/LICENSE-2.0
	
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
	
Filename: /admin/templates/list.php

Purpose: Lists the current templates in the database and allows them to be edited, deleted,
	and new ones to be created.
	
Processed parameters: (TYPE - NAME - DESCRIPTION - DEFAULT)
	NONE
*******************************************************************************/

require_once '../includes/admin_standard.php';

// Check for any requested actions
//////////
// Create new
if(isset($_POST['create']))
{
	// Ensure a valid name was entered
	if(isset($_POST['name']) && !empty($_POST['name']) && isValidTemplateName($connection, $_POST['name']))
	{		
		// Create template
		$success = createTemplate($connection, $_POST['name'], $_POST['description'], '',
			(isset($_POST['inclusion']) ? true : false), isset($_POST['linked_data_page']));
		
		if($success !== false)
		{
			$message = 'Template successfully created.';
			header('Location: edit.php?name=' . $_POST['name'] . '&message=' . urlencode($message));
			die();
		}
		else
		{
			$message = 'Template was not successfully created.';		}
	}
	else
	{
		$message = 'You must enter a <em>valid</em> name.';
	}
}
//////////
// Edit
elseif(isset($_POST['edit']))
{
	// Ensure that a template (and only one) was selected
	if(isset($_POST['template']) && count($_POST['template']) == 1)
	{
		header("Location: edit.php?name={$_POST['template'][0]}");	
	}
	else
	{
		$message = "You must select a template (only one at a time) you would like to edit.";
	}
}
//////////
// Delete
elseif(isset($_POST['delete']))
{
	// Ensure that at least one template was selected
	if(isset($_POST['template']) && count($_POST['template']) >= 1)
	{
		// Save the template names so that they can be used in the redirect
		$templatesToBeRemoved = implode(',', $_POST['template']);
		header("Location: delete.php?name={$templatesToBeRemoved}");	
	}
	else
	{
		$message = "You must select the template(s) you would like to remove.";
	}
}

include '../includes/header.php';
?>
<h1>Current Templates</h1>
<p>Below is a list of templates currently in this site. Select templates by clicking on the check box next to the
one you want. Use the buttons below the list to perform actions on the selected templates. Some options are only
available for one item at a time. Click on a template name to see a preview of it. (Opens in a new window.)</p>
<p>Note: LDP stands for <strong>L</strong>inked <strong>D</strong>ata <strong>P</strong>age. Click on
the "Yes" to edit each one.</p>
<table class="itemlist">
	<tr class="head">
		<td></td>
		<td>Name</td>
		<td>Description</td>
		<td>Include</td>
		<td>LDP</td>
	</tr>
	<?php
	// Display list of templates
	$templates = getTemplateList($connection);
	if(is_array($templates) && !empty($templates))
	{
		foreach($templates as $current)
		{
			?>
			<tr>
				<td>
					<input type="checkbox" name="template[]"
						value="<?php echo $current['template_name']; ?>" />
				</td>
				<td><a href="../../showtemplate.php?template=<?php echo $current['template_name']; ?>"
					target="_blank"><?php echo $current['template_name']; ?></a></td>
				<td><?php echo $current['description']; ?></td>
				<td><?php echo ($current['inclusion'] == true ? 'Yes' : ''); ?></td>
				<td>
					<?php
					// Linked data page? Give a link to edit it if there is one
					if($current['linked_data_page'] == true)
					{
						echo "<a href='../pages/edit.php?name=" . $linked_data_page_name_prefix
							. $current['template_name']	. "&amp;linked_page'>Yes</a>";
					}
					?>
				</td>
			</tr>
			<?php
		}
	}
	else
	{
		?>
		<tr>
			<td colspan='5'><strong>No templates were available.</strong></td>
		</tr>
		<?php
	}
	?>
	<tr>
		<td></td>
		<td><input type="text" name="name" maxlength="255" /></td>
		<td><input type="text" name="description" maxlength="255" /></td>
		<td><input type="checkbox" name="inclusion" /></td>
		<td><input type="checkbox" name="linked_data_page" /></td>
		<td><input type="submit" name="create" value="Create New" /></td>
	</tr>
</table>
<input type="submit" name="edit" value="Edit" />
<input type="submit" name="delete" value="Delete" />
<?php
include '../includes/footer.php';
?>