<?php
/*******************************************************************************
License:
	Copyright 2005 Ryan Morehart
	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at
	
	http://www.apache.org/licenses/LICENSE-2.0
	
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
	
Filename: /admin/users/edit.php

Purpose: Presents form with current user data and allows it to be changed and updated
	in the database.

Processed parameters: (TYPE - NAME - DESCRIPTION - DEFAULT)
	GET - name - Name of user to be edited.
*******************************************************************************/

require_once '../includes/admin_standard.php';

// Ensure an existent user was supplied
if((!isset($_GET['name']) || !isValidUserName($connection, $_GET['name'], true))
	&& !isset($_SESSION['name']))
{
	returnToCaller('No user specified');
	die();
}

// Store the user name
if(isset($_GET['name']))
{
	$_SESSION['name'] = $_GET['name'];
}

//////////////
// Update information of user
if(isset($_POST['infosubmit']))
{
	if(setUserInfo($connection, $_SESSION['name'], $_POST['name'], $_POST['password']))
	{
		$message = 'The user information was successfully updated.';
	}
	else
	{
		$message = 'User information update failed.';
	}
}
/////////////
// Update permissions
elseif(isset($_POST['permissionsubmit']))
{
	// Build permission string
	$permissions = '';
	foreach($_POST['permission'] as $current)
	{
		$permissions .= $current;
	}
	
	// Attempt to set
	if(setUserPermissions($connection, $_SESSION['name'], $permissions))
	{
		$message = 'The user permissions were successfully updated.';
	}
	else
	{
		$message = 'The user permissions failed to update successfully.';
	}
}

// Get user data
$user = getUser($connection, $_SESSION['name']);

include '../includes/header.php';
?>
<h1>Editing user <?php echo $_SESSION['name']; ?></h1>
<p>You are currently editing a user of this site. Any changes made here will be applied to them the next
time they login. (Note that if they are logged in when the changes are submitted the old settings will still
apply until they logout.)</p>

<h2>User info</h2>
<p>Use the form below to change the user's name and password. It is impossible to clear the user's password.
If you leave the password field blank, the user's current password will still be used.</p>
<table>
	<tr>
		<td>Username:</td>
		<td><input type="text" maxlength="25" name="name" value="<?php echo $user['user_name']; ?>" /></td>
	</tr>
	<tr>
		<td>Password:</td>
		<td><input type="password" name="password" /></td>
	</tr>
</table>
<input type="submit" name="infosubmit" value="Update info" />

<h2>Permissions</h2>
<p>Use the various checkboxes below to set what this user is allowed to do. </p>
<table class="itemlist">
	<tr class="head">
		<td></td>
		<td>Allow</td>
		<td>Default</td>
		<td>Deny</td>
	</tr>
	<tr>
		<td><strong>Default to</strong></td>
		<td>
			<input type="radio" name="permission[all]" value="+all"
				<?php
				echo (strstr($user['permissions'], "+all") ? 'checked="true"' : '');
				?>
			/>
		</td>
		<td>
			<input type="radio" name="permission[all]" value="" 
				<?php
				if(!(strstr($user['permissions'], "+all")
					|| strstr($user['permissions'], "-all")))
				{
					echo 'checked="true"';
				}
				?>
			/>
		</td>
		<td>
			<input type="radio" name="permission[all]" value="-all"
				<?php
				echo (strstr($user['permissions'], "-all") ? 'checked="true"' : '');
				?>
			/>
		</td>
	</tr>
	<?php
	// Loop through available actions
	foreach($available_site_actions as $current)
	{
		?>
		<tr>
			<td><?php echo ucwords(str_replace('_', ' ', $current)); ?></td>
			<td>
				<input type="radio" name="permission[<?php echo $current; ?>]"
					value="+<?php echo $current; ?>"
					<?php
					echo (strstr($user['permissions'], "+{$current}") ? 'checked="true"' : '');
					?>
				/>
			</td>
			<td>
				<input type="radio" name="permission[<?php echo $current; ?>]"
					value=""
					<?php
					if(!(strstr($user['permissions'], "+$current")
						|| strstr($user['permissions'], "-$current")))
					{
						echo 'checked="true"';
					}
					?>
				/>
			</td>
			<td>
				<input type="radio" name="permission[<?php echo $current; ?>]"
					value="-<?php echo $current; ?>"
					<?php
					echo (strstr($user['permissions'], "-$current") ? 'checked="true"' : '');
					?>
				/>
			</td>
		</tr>
		<?php
	}
	?>
</table>
<input type="submit" name="permissionsubmit" value="Update permissons" />
<?php
include '../includes/footer.php';
?>