<?php
/*******************************************************************************
License:
	Copyright 2005 Ryan Morehart
	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at
	
	http://www.apache.org/licenses/LICENSE-2.0
	
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
	
Filename: /admin/users/list.php

Purpose: Lists the current users in the database and allows them to be edited, deleted,
	and new ones to be created.
	
Processed parameters: (TYPE - NAME - DESCRIPTION - DEFAULT)
	NONE
*******************************************************************************/

require_once '../includes/admin_standard.php';

// Check for any requested actions
//////////////
// Create new
if(isset($_POST['create']))
{
	// Ensure that a (valid) name was entered
	if(isValidUserName($connection, $_POST['username'], false))
	{
		// Create user
		if(createUser($connection, $_POST['username'], $_POST['password'], $_POST['permissions']))
		{
			$message = 'The user was successfully created.';
			header('Location: edit.php?name=' . $_POST['username'] . '&message=' . urlencode($message));
			die();
		}
		else
		{
			$message = 'The user was not successfully created.';
		}
	}
	else
	{
		$message = 'You must enter a <em>valid</em> name.';
	}
}
//////////
// Edit
elseif(isset($_POST['edit']))
{
	// Ensure that a user (and only one), was selected
	if(isset($_POST['user']) && count($_POST['user']) == 1)
	{
		header("Location: edit.php?name={$_POST['user'][0]}");	
	}
	else
	{
		$message = "You must select a user (only one at a time) you would like to edit.";
	}
}
//////////
// Delete
elseif(isset($_POST['delete']))
{
	// Ensure that at least one user was selected
	if(isset($_POST['user']) && count($_POST['user']) >= 1)
	{
		// Save the user names so that they can be used in the redirect
		$usersToBeRemoved = implode(',', $_POST['user']);
		header("Location: delete.php?name={$usersToBeRemoved}");	
	}
	else
	{
		$message = "You must select the user(s) you would like to remove.";
	}
}
//////////
// Become selected
elseif(isset($_POST['become']))
{
	// Ensure that a user (and only one), was selected
	if(isset($_POST['user']) && count($_POST['user']) == 1)
	{
		header("Location: become.php?name={$_POST['user'][0]}");
	}
	else
	{
		$message = "You must select a user (only one at a time) you would like to become.";
	}
}

include '../includes/header.php';
?>
<h1>Current Users</h1>
<p>Below is a list of users who are able to edit this site. From this screen, you can add new users, delete
current ones, change passwords, and change user's permissions.</p>
<table class="itemlist">
	<tr class="head">
		<td></td>
		<td>Username</td>
		<td>Password</td>
		<td>Permissions</td>
	</tr>
	<?php
	// Display list of users
	$users = getUserList($connection);
	if(is_array($users) && !empty($users))
	{
		foreach($users as $current)
		{
			?>
			<tr>
				<td><input type="checkbox" name="user[]" value="<?php echo $current['user_name']; ?>" /></td>
				<td><?php echo $current['user_name']; ?></td>
				<td>&lt;hidden&gt;</td>
				<td><?php echo $current['permissions']; ?></td>
			</tr>
			<?php
		}
	}
	else
	{
		?>
		<tr>
			<td colspan='4'><strong>No users were available.</strong></td>
		</tr>
		<?php
	}
	?>
	<tr>
		<td></td>
		<td><input type="text" maxlength="25" name="username" /></td>
		<td><input type="password" name="password" /></td>
		<td>
			<select name="permissions">
				<?php
				// Go through the common permissions settings
				foreach($common_permissions as $name => $setting)
				{
					echo "<option value='$setting'>$name</option>";
				}
				?>
			</select>
		</td>
		<td><input type="submit" name="create" value="Create New" /></td>
	</tr>
</table>
<input type="submit" name="edit" value="Edit" />
<input type="submit" name="delete" value="Delete" />
<input type="submit" name="become" value="Become user" />
<?php
include '../includes/footer.php';
?>