<?php
/*******************************************************************************
License:
	Copyright 2005 Ryan Morehart
	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at
	
	http://www.apache.org/licenses/LICENSE-2.0
	
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
	
Filename: /showimage.php

Purpose: Runs the specified file the specified number of times and records the time it takes
	for it to complete. Displays results and the average afterward.

Processed parameters: (TYPE - NAME - DESCRIPTION - DEFAULT)
	GET - name - filename to benchmark
	GET - runs - number of times to run the file - $benchmark_times in settings.php
*******************************************************************************/

require_once 'includes/user_standard.php';

// Check if benchmarking is enabled
if(!$enable_benchmarking)
{
	die('Benchmarking is disabled.');
}

// Make sure a file was specified
if(!isset($_GET['name']))
{
	die('Please specify a file to benchmark.');
}

if(isset($_GET['runs']))
{
	$benchRuns = $_GET['runs'];
}
else
{
	$benchRuns = $benchmark_times;
}

// Turn on buffering so output isn't sent
ob_start();

// Benchmark! Get the various times each one takes. We'll calculate afterward
$results = array();
for($i = 0; $i < $benchRuns; $i++)
{
	// Run file, getting beginning and ending times
	$__beginTime = microtime();
	include $_GET['name'];
	$__endTime = microtime();
	
	// Calculate length and save
	$beginChunks = explode(' ', $__beginTime);
	$endChunks = explode(' ', $__endTime);
	$seconds = $endChunks[1] - $beginChunks[1];
	$microseconds = $endChunks[0] - $beginChunks[0];
	$total = $seconds + $microseconds;
	$results[$i + 1] = $total;
	
	// Clear buffer
	ob_clean();
}

// Clean and end output buffer
ob_end_clean();
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
<head>
	<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
	<title>Benchmark</title>
	<link href="admin/includes/stylesheets/normal.css" rel="stylesheet" type="text/css">
</head>

<body>
<h1>Benchmark results</h1>
<p>Below are the raw results for <?php echo $_GET['name']; ?>. The average time taken was <?php
echo array_sum($results) / count($results); ?> seconds.</p>
<table class="itemlist">
	<tr class="head">
		<td>Trial</td>
		<td>Time</td>
	</tr>
	
	<?php
	foreach($results as $number => $time)
	{
		?>
		<tr>
			<td><?php echo $number; ?></td>
			<td><?php echo $time; ?></td>
		</tr>
		<?php
	}
	?>
	
</table>
</body>
</html>
