<?php
/*******************************************************************************
License:
	Copyright 2005 Ryan Morehart
	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at
	
	http://www.apache.org/licenses/LICENSE-2.0
	
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
	
Filename: /showimage.php

Purpose: Displays images stored in database. Supports dynamic resizing.

Processed parameters: (TYPE - NAME - DESCRIPTION - DEFAULT)
	GET - name - name of image to display
	GET - height - height of image (in pixels) - Original height or largest to match width in proportional
		mode
	GET - width - width of image (in pixels) -  Original width or largest to match height in proportional
		mode
	GET - height - height of image (in pixels)
	GET - proportional - display mode of image
		stretch - force image to fill dimensions specified by height and width
		anything else - fills blank space with background color
*******************************************************************************/

require_once 'includes/user_standard.php';

// Ensure an image name was supplied
if(!isset($_GET['name']))
{
	$error = "No image specified";
	$type = 'image/gif';
	$originalHeight = 100;
	$originalWidth = 100;
}
else
{
	// Determine if the name is valid
	$image = getImage($connection, $_GET['name']);
	
	if($image !== false)
	{
		$original = @imagecreatefromstring($image['image_data']);
		
		// Check if the image was found
		if($original !== false)
		{
			// Find the original's dimensions
			$type = $image['image_type'];
			$originalHeight = ImageSy($original);
			$originalWidth = ImageSx($original);
		}
		else
		{
			// Image format appears to be bad
			$error = "Image format possibly bad";
			$type = 'image/gif';
			$originalHeight = 100;
			$originalWidth = 100;
		}
	}
	else
	{
		// Image was not successfully opened
		$error = "Image not successfully opened";
		$type = 'image/gif';
		$originalHeight = 100;
		$originalWidth = 100;
	}
}

// Find what the new dimensions are supposed to be
if(isset($_GET['height']) || isset($_GET['width']))
{
	$newHeight = $_GET['height'];
	$newWidth = $_GET['width'];
}
else
{
	$newHeight = $originalHeight;
	$newWidth = $originalWidth;
}

// Create the canvas for the new (resized) image
$new = imagecreatetruecolor($newWidth, $newHeight);
imagealphablending($new, true);
$transparent = imagecolorresolvealpha($new, 255, 255, 255, 0);
imagefilledrectangle($new, 0, 0, $newWidth, $newHeight, $transparent);

// Check if we are doing a proportional thing or just stretching it
if(!isset($_GET['proportional']) || $_GET['proportional'] != 'stretch')
{
	// Which dimension is the more limiting factor?
	$percentWidth = $newWidth / $originalWidth;
	$percentHeight = $newHeight / $originalHeight;
	
	if($percentWidth <= $percentHeight)
	{
		// Width more limiting
		$newHeight = $originalHeight * $percentWidth;
	}
	else
	{
		// Height more limiting
		$newWidth = $originalWidth * $percentHeight;
	}
}

// Check if an error has occured
if(!isset($error))
{
	// Copy image
	imagecopyresampled($new, $original, 0, 0, 0, 0, $newWidth, $newHeight, $originalWidth, $originalHeight);
}
else
{
	// Output error string on image
	$black = imagecolorresolvealpha($new, 0, 0, 0, 0);
	$errorStrings = explode(' ', $error);
	foreach($errorStrings as $number => $current)
		imagestring($new, 3, 0, $number * 10, $current, $black);
}

// Output in the same type as the original image
switch($type)
{
case 'image/jpg':
case 'image/jpeg':
	header('Content-type: image/jpeg');
	imagejpeg($new);
	break;

case 'image/gif':
	header('Content-type: image/gif');
	imagegif($new);
	break;
	
case 'image/png':
default:
	header('Content-type: image/png');
	imagepng($new);
	break;
}
?>